package com.ruoyi.web.controller.business;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import io.swagger.annotations.*;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.Result;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.business.domain.TeamInfo;
import com.ruoyi.business.domain.req.TeamInfoQueryReq;
import com.ruoyi.business.domain.req.TeamInfoSaveReq;
import com.ruoyi.business.domain.req.TeamInfoEditReq;
import com.ruoyi.business.service.TeamInfoService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 小组Controller
 *
 * @author ruoyi
 * @date 2024-04-23
 */
@Api(tags = "小组管理")
@RestController
@RequestMapping("/business/team")
public class TeamInfoController extends BaseController {

    @Autowired
    private TeamInfoService teamInfoService;

    /**
     * 查询小组列表
     */
    @ApiOperation("获取小组列表")
    @PreAuthorize("@ss.hasPermi('business:team:list')")
    @GetMapping("/list")
    public Result<TableDataInfo<TeamInfo>> list(TeamInfoQueryReq teamInfoQueryReq) {
        startPage();
        List<TeamInfo> list = teamInfoService.list(TeamInfo.queryBuild(teamInfoQueryReq));
        return getDataTable(list);
    }

    /**
     * 导出小组列表
     */
    @ApiOperation("导出小组列表")
    @PreAuthorize("@ss.hasPermi('business:team:export')")
    @Log(title = "小组", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, TeamInfo teamInfo) {
        List<TeamInfo> list = teamInfoService.list(teamInfo);
        ExcelUtil<TeamInfo> util = new ExcelUtil<TeamInfo>(TeamInfo.class);
        util.exportExcel(response, list, "小组数据");
    }

    /**
     * 获取小组详细信息
     */
    @ApiOperation("获取小组详细信息")
    @PreAuthorize("@ss.hasPermi('business:team:query')")
    @GetMapping(value = "/{teamId}")
    @ApiImplicitParam(name = "teamId", value = "teamId", required = true, dataType = "Long", paramType = "path", dataTypeClass = Long.class)
    public Result<TeamInfo> getInfo(@PathVariable("teamId") Long teamId) {
        return Result.success(teamInfoService.getById(teamId));
    }

    /**
     * 新增小组
     */
    @PreAuthorize("@ss.hasPermi('business:team:add')")
    @Log(title = "小组", businessType = BusinessType.INSERT)
    @PostMapping
    @ApiOperation("新增小组")
    public Result<String> add(@RequestBody TeamInfoSaveReq teamInfoSaveReq) {
        return toAjax(teamInfoService.save(TeamInfo.saveBuild(teamInfoSaveReq)));
    }

    /**
     * 修改小组
     */
    @PreAuthorize("@ss.hasPermi('business:team:edit')")
    @Log(title = "小组", businessType = BusinessType.UPDATE)
    @PutMapping("/{teamId}")
    @ApiOperation("修改小组")
    public Result<String> edit(@PathVariable Long teamId, @RequestBody TeamInfoEditReq teamInfoEditReq) {
        return toAjax(teamInfoService.updateById(TeamInfo.editBuild(teamId,teamInfoEditReq)));
    }

    /**
     * 删除小组
     */
    @PreAuthorize("@ss.hasPermi('business:team:remove')")
    @Log(title = "小组", businessType = BusinessType.DELETE)
	@DeleteMapping("/{teamIds}")
    @ApiOperation("删除小组")
    @ApiImplicitParam(name = "teamId", value = "teamId", required = true, dataType = "Long", paramType = "path", dataTypeClass = String.class, example = "1,2,3,4")
    public Result<String> remove(@PathVariable List<Long> teamIds) {
        return toAjax(teamInfoService.removeBatchByIds(teamIds));
    }
}
